# Dictio
A very simple python command line English dictionary tool
## Install
$pip install dictiopy
## Usage
Type one word as input argument.


```
$dictio hello

hello  /həˈləʊ/
Noun
1. "Hello!" or an equivalent greeting.
Verb
2. To greet with "hello".
Interjection
3. A greeting (salutation) said when meeting someone or acknowledging someone’s arrival or presence.
4. A greeting used when answering the telephone.
5. A call for response if it is not clear if anyone is present or listening, or if a telephone conversation may have been disconnected.
6. Used sarcastically to imply that the person addressed or referred to has done something the speaker or writer considers to be foolish.
7. An expression of puzzlement or discovery.
```
## Dependencies
[FreeDcitionaryApi](https://dictionaryapi.dev/)
